@@ -7,5 +7,5 @@ __all__ = ["MultiPartCodec"]
 class MultiPartCodec(HTTPCodec):
     media_type = "multipart/form-data"
 
-    async def decode(self, request: http.Request, **options):
-        return await request.form()
+    async def decode(self, item: http.Request, **options):
+        return await item.form()
